"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useAdminNavigationCommands = useAdminNavigationCommands;
var _commands = require("@wordpress/commands");
var _i18n = require("@wordpress/i18n");
var _icons = require("@wordpress/icons");
var _url = require("@wordpress/url");
var _router = require("@wordpress/router");
var _hooks = require("./hooks");
var _lockUnlock = require("./lock-unlock");
/**
 * WordPress dependencies
 */

/**
 * Internal dependencies
 */

const {
  useHistory
} = (0, _lockUnlock.unlock)(_router.privateApis);
function useAdminNavigationCommands() {
  const history = useHistory();
  const isTemplatesAccessible = (0, _hooks.useIsTemplatesAccessible)();
  const isBlockBasedTheme = (0, _hooks.useIsBlockBasedTheme)();
  const isSiteEditor = (0, _url.getPath)(window.location.href)?.includes('site-editor.php');
  (0, _commands.useCommand)({
    name: 'core/add-new-post',
    label: (0, _i18n.__)('Add new post'),
    icon: _icons.plus,
    callback: () => {
      document.location.href = 'post-new.php';
    }
  });
  (0, _commands.useCommand)({
    name: 'core/add-new-page',
    label: (0, _i18n.__)('Add new page'),
    icon: _icons.plus,
    callback: () => {
      document.location.href = 'post-new.php?post_type=page';
    }
  });
  (0, _commands.useCommand)({
    name: 'core/manage-reusable-blocks',
    label: (0, _i18n.__)('Patterns'),
    icon: _icons.symbol,
    callback: ({
      close
    }) => {
      if (isTemplatesAccessible && isBlockBasedTheme) {
        const args = {
          path: '/patterns'
        };
        if (isSiteEditor) {
          history.push(args);
        } else {
          document.location = (0, _url.addQueryArgs)('site-editor.php', args);
        }
        close();
      } else {
        document.location.href = 'edit.php?post_type=wp_block';
      }
    }
  });
}
//# sourceMappingURL=admin-navigation-commands.js.map